==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/PrivilegedSignupStatus.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

import odata.msgraph.client.beta.enums.SetupStatus;

@JsonPropertyOrder({
    "@odata.type", 
    "isRegistered", 
    "status"})
@JsonInclude(Include.NON_NULL)
public class PrivilegedSignupStatus extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.privilegedSignupStatus";
    }

    @JsonProperty("isRegistered")
    protected Boolean isRegistered;

    @JsonProperty("status")
    protected SetupStatus status;

    protected PrivilegedSignupStatus() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderPrivilegedSignupStatus() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private Boolean isRegistered;
        private SetupStatus status;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder isRegistered(Boolean isRegistered) {
            this.isRegistered = isRegistered;
            this.changedFields = changedFields.add("isRegistered");
            return this;
        }

        public Builder status(SetupStatus status) {
            this.status = status;
            this.changedFields = changedFields.add("status");
            return this;
        }

        public PrivilegedSignupStatus build() {
            PrivilegedSignupStatus _x = new PrivilegedSignupStatus();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.privilegedSignupStatus";
            _x.id = id;
            _x.isRegistered = isRegistered;
            _x.status = status;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @Property(name="isRegistered")
    @JsonIgnore
    public Optional<Boolean> getIsRegistered() {
        return Optional.ofNullable(isRegistered);
    }

    public PrivilegedSignupStatus withIsRegistered(Boolean isRegistered) {
        PrivilegedSignupStatus _x = _copy();
        _x.changedFields = changedFields.add("isRegistered");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.privilegedSignupStatus");
        _x.isRegistered = isRegistered;
        return _x;
    }

    @Property(name="status")
    @JsonIgnore
    public Optional<SetupStatus> getStatus() {
        return Optional.ofNullable(status);
    }

    public PrivilegedSignupStatus withStatus(SetupStatus status) {
        PrivilegedSignupStatus _x = _copy();
        _x.changedFields = changedFields.add("status");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.privilegedSignupStatus");
        _x.status = status;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public PrivilegedSignupStatus patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        PrivilegedSignupStatus _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public PrivilegedSignupStatus put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        PrivilegedSignupStatus _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private PrivilegedSignupStatus _copy() {
        PrivilegedSignupStatus _x = new PrivilegedSignupStatus();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.isRegistered = isRegistered;
        _x.status = status;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("PrivilegedSignupStatus[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("isRegistered=");
        b.append(this.isRegistered);
        b.append(", ");
        b.append("status=");
        b.append(this.status);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/PrivilegedSignupStatus.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Boolean;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

import odata.msgraph.client.beta.enums.SetupStatus;

@JsonPropertyOrder({
    "@odata.type", 
    "isRegistered", 
    "status"})
@JsonInclude(Include.NON_NULL)
public class PrivilegedSignupStatus extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.privilegedSignupStatus";
    }

    @JsonProperty("isRegistered")
    protected Boolean isRegistered;

    @JsonProperty("status")
    protected SetupStatus status;

    protected PrivilegedSignupStatus() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderPrivilegedSignupStatus() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private Boolean isRegistered;
        private SetupStatus status;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder isRegistered(Boolean isRegistered) {
            this.isRegistered = isRegistered;
            this.changedFields = changedFields.add("isRegistered");
            return this;
        }

        public Builder status(SetupStatus status) {
            this.status = status;
            this.changedFields = changedFields.add("status");
            return this;
        }

        public PrivilegedSignupStatus build() {
            PrivilegedSignupStatus _x = new PrivilegedSignupStatus();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.privilegedSignupStatus";
            _x.id = id;
            _x.isRegistered = isRegistered;
            _x.status = status;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    @Property(name="isRegistered")
    @JsonIgnore
    public Optional<Boolean> getIsRegistered() {
        return Optional.ofNullable(isRegistered);
    }

    public PrivilegedSignupStatus withIsRegistered(Boolean isRegistered) {
        PrivilegedSignupStatus _x = _copy();
        _x.changedFields = changedFields.add("isRegistered");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.privilegedSignupStatus");
        _x.isRegistered = isRegistered;
        return _x;
    }

    @Property(name="status")
    @JsonIgnore
    public Optional<SetupStatus> getStatus() {
        return Optional.ofNullable(status);
    }

    public PrivilegedSignupStatus withStatus(SetupStatus status) {
        PrivilegedSignupStatus _x = _copy();
        _x.changedFields = changedFields.add("status");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.privilegedSignupStatus");
        _x.status = status;
        return _x;
    }

    public PrivilegedSignupStatus withUnmappedField(String name, Object value) {
        PrivilegedSignupStatus _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public PrivilegedSignupStatus patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        PrivilegedSignupStatus _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public PrivilegedSignupStatus put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        PrivilegedSignupStatus _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private PrivilegedSignupStatus _copy() {
        PrivilegedSignupStatus _x = new PrivilegedSignupStatus();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.isRegistered = isRegistered;
        _x.status = status;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("PrivilegedSignupStatus[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("isRegistered=");
        b.append(this.isRegistered);
        b.append(", ");
        b.append("status=");
        b.append(this.status);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
